@@ -1,4 +1,4 @@
-# $Id: Request.pm 46806 2017-07-26 15:48:10Z wsl $
+# $Id: Request.pm 46832 2017-08-01 11:08:55Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Person/Delete/Request.pm $
 
 package UvT::Kiki::WS::Person::Delete::Request;
@@ -15,19 +15,20 @@ field new_person => sub {
 	if($self->nonce) {
 		if($self->is_robot) {
 			if($person) {
+				my $original = $person->original;
 				my $note = $person->remove;
 				$self->note($note);
 
 				if($note->[0] eq 'ok') {
 					my $what = $self->is_robot ? "Robot" : "User";
 					my $who = $self->login;
-					my $old = $person->toString;
+					my $old = $original->toString;
 					my $text = "$what $who deleted person:\n\told: $old\n";
 					warn $text;
 
-					my $full = $person->full;
-					my $anr = sprintf('%06d', $person->anr);
-					$self->mailtje("[kiki] $who deleted $full ($anr)", $person->diff);
+					my $full = $original->full;
+					my $anr = sprintf('%06d', $original->anr);
+					$self->mailtje("[kiki] $who deleted $full ($anr)", $original->diff);
 					$self->activate;
 				}
 			} else {
