@@ -1,4 +1,4 @@
-# $Id: Request.pm 46806 2017-07-26 15:48:10Z wsl $
+# $Id: Request.pm 47136 2017-11-02 13:44:40Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Person/Put/Request.pm $
 
 use utf8;
@@ -63,12 +63,10 @@ field new_person => sub {
 			my $anr = sprintf('%06d', $anr);
 			if(my $original = $person->original) {
 				my $old = $original->toString;
-				my $text = "$what $who updated person $full ($anr):\n\told: $old\n\tnew: $new\n";
-				warn $text;
+				warn "$what $who updated person $full ($anr):\n\told: $old\n\tnew: $new\n";
 				$self->mailtje("[kiki] $who updated $full ($anr)", $person->diff);
 			} else {
-				my $text = "$what $who created person $full ($anr):\n\tnew: $new\n";
-				warn $text;
+				warn "$what $who created person $full ($anr):\n\tnew: $new\n";
 				$self->mailtje("[kiki] $who created $full ($anr)", $person->diff);
 			}
 
